'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.token = undefined;

exports.default = function (server) {
	var port = arguments.length <= 1 || arguments[1] === undefined ? 6021 : arguments[1];
	var bytes = arguments.length <= 2 || arguments[2] === undefined ? 64 : arguments[2];

	exports.token = token = (0, _crypto.randomBytes)(bytes).toString('hex');

	server.once('started', function () {
		server.client = (0, _deepstream2.default)('localhost:' + port).login({
			serverToken: token
		});
		server.emit('clientReady');
	});
};

exports.isServerAuth = isServerAuth;
exports.isServer = isServer;
exports.extendPermissionHandler = extendPermissionHandler;

var _crypto = require('crypto');

var _deepstream = require('deepstream.io-client-js');

var _deepstream2 = _interopRequireDefault(_deepstream);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var token;

function isServerAuth(conn, auth, cb) {
	if (auth.serverToken) {
		if (auth.serverToken === token) {
			cb(null, auth.serverToken);
		} else {
			cb('Unauthorized.');
		}
		return true;
	}
	return false;
}

function isServer(clientUsername) {
	return clientUsername === token;
}

function extendPermissionHandler(permissionHandler) {
	return {
		isValidUser: function isValidUser(conn, auth, cb) {
			if (isServerAuth(conn, auth, cb)) {
				// Server authenticated
				return;
			}
			return permissionHandler.isValidUser(conn, auth, cb);
		},
		canPerformAction: function canPerformAction(username, message, cb) {
			if (isServer(username)) {
				// Allow server full access
				return cb(null, true);
			}
			return permissionHandler.canPerformAction(username, message, cb);
		},
		onClientDisconnect: function onClientDisconnect(username) {
			return permissionHandler.onClientDisconnect(username);
		}
	};
}

exports.token = token;